clear all
cap close
set more off
set excelxlsxlargefile on

cd ""

use mortgage_statistics_dataset_rate_decrease.dta,clear 

keep if frm==1

keep if inlist(term,24,36,48,60)

keep if reset_mon>=m(2010m1)

keep if reset_renew==1 

drop if lifecy>term+18

drop if month>m(2017m1)

drop if postrenew_reco==. 

sort tu_consumer_id open_mon tu_trade_id month
by tu_consumer_id open_mon tu_trade_id: gen dyn_postrenew = sum(postrenew_reco)
by tu_consumer_id open_mon tu_trade_id: replace dyn_postrenew= 100 if dyn_postrenew[_n+1]==1
by tu_consumer_id open_mon tu_trade_id: replace dyn_postrenew= 200 if dyn_postrenew[_n+2]==1
by tu_consumer_id open_mon tu_trade_id: replace dyn_postrenew= 300 if dyn_postrenew[_n+3]==1
by tu_consumer_id open_mon tu_trade_id: replace dyn_postrenew= 400 if dyn_postrenew[_n+4]==1
by tu_consumer_id open_mon tu_trade_id: replace dyn_postrenew= 500 if dyn_postrenew[_n+5]==1
by tu_consumer_id open_mon tu_trade_id: replace dyn_postrenew= 600 if dyn_postrenew[_n+6]==1
by tu_consumer_id open_mon tu_trade_id: replace dyn_postrenew= 700 if dyn_postrenew[_n+7]==1
by tu_consumer_id open_mon tu_trade_id: replace dyn_postrenew= 800 if dyn_postrenew[_n+8]==1
by tu_consumer_id open_mon tu_trade_id: replace dyn_postrenew= 900 if dyn_postrenew[_n+9]==1

tab dyn_postrenew 

gen dyn_qt = dyn_postrenew
replace dyn_qt = 1 if inlist(dyn_postrenew,1,2,3)
replace dyn_qt = 2 if inlist(dyn_postrenew,4,5,6)
replace dyn_qt = 3 if inlist(dyn_postrenew,7,8,9)
replace dyn_qt = 4 if inlist(dyn_postrenew,10,11,12)
replace dyn_qt = 5 if inlist(dyn_postrenew,13,14,15)
replace dyn_qt = 6 if dyn_postrenew>=16 & dyn_postrenew!=.

replace dyn_qt = 100 if inlist(dyn_postrenew,100,200,300)
replace dyn_qt = 200 if inlist(dyn_postrenew,400,500,600)
replace dyn_qt = 300 if inlist(dyn_postrenew,700,800,900)
tab dyn_qt

replace dyn_qt = 400 if dyn_qt==0
replace dyn_qt = 0 if dyn_qt==100

* Regressions
foreach x of varlist newauto newinstall {
foreach tt of numlist 60{
quietly xtreg `x' i.dyn_qt lagcscore age lagfsaltv i.month if term==`tt',fe r
estimates store `x'_dyn_`tt'
}
}

estimates table newauto_dyn_60,keep(300.dyn_qt 200.dyn_qt 1.dyn_qt 2.dyn_qt 3.dyn_qt 4.dyn_qt 5.dyn_qt) b(%7.3f) se(%7.3f) stats(N)
estimates table newinstall_dyn_60,keep(300.dyn_qt 200.dyn_qt 1.dyn_qt 2.dyn_qt 3.dyn_qt 4.dyn_qt 5.dyn_qt) b(%7.3f) se(%7.3f) stats(N)

quietly xtreg newauto dyn_qt_* lagcscore age lagfsaltv i.month if term==60, fe r  
lincom 3*dyn_qt_300
mat A = r(estimate), r(se)
mat rownames A = 300
lincom 3*dyn_qt_200
mat B = r(estimate), r(se)
mat rownames B = 200
lincom 3*dyn_qt_1
mat C = r(estimate), r(se)
mat rownames C = 1
lincom 3*(dyn_qt_1+dyn_qt_2)
mat D = r(estimate), r(se)
mat rownames D = 2
lincom 3*(dyn_qt_1+dyn_qt_2+dyn_qt_3)
mat E = r(estimate), r(se)
mat rownames E = 3
lincom 3*(dyn_qt_1+dyn_qt_2+dyn_qt_3+dyn_qt_4)
mat F = r(estimate), r(se)
mat rownames F = 4
lincom 3*(dyn_qt_1+dyn_qt_2+dyn_qt_3+dyn_qt_4+dyn_qt_5)
mat E = r(estimate), r(se)
mat rownames E = 5
mat J = A\B\C\D\E\F
mat colnames J = estimate se
mat list J

quietly xtreg newinstall dyn_qt_* lagcscore age lagfsaltv i.month if term==60, fe r  
lincom 3*dyn_qt_300
mat A = r(estimate), r(se)
mat rownames A = 300
lincom 3*dyn_qt_200
mat B = r(estimate), r(se)
mat rownames B = 200
lincom 3*dyn_qt_1
mat C = r(estimate), r(se)
mat rownames C = 1
lincom 3*(dyn_qt_1+dyn_qt_2)
mat D = r(estimate), r(se)
mat rownames D = 2
lincom 3*(dyn_qt_1+dyn_qt_2+dyn_qt_3)
mat E = r(estimate), r(se)
mat rownames E = 3
lincom 3*(dyn_qt_1+dyn_qt_2+dyn_qt_3+dyn_qt_4)
mat F = r(estimate), r(se)
mat rownames F = 4
lincom 3*(dyn_qt_1+dyn_qt_2+dyn_qt_3+dyn_qt_4+dyn_qt_5)
mat E = r(estimate), r(se)
mat rownames E = 5
mat J = A\B\C\D\E\F
mat colnames J = estimate se
mat list J

